@@ -10,10 +10,11 @@ from fastapi_users.exceptions import (
 from fief.apps.auth.forms.reset import ForgotPasswordForm, ResetPasswordForm
 from fief.dependencies.auth import get_optional_login_session
 from fief.dependencies.tenant import get_current_tenant
+from fief.dependencies.theme import get_current_theme
 from fief.dependencies.users import UserManager, get_user_manager
 from fief.forms import FormHelper
 from fief.locale import gettext_lazy as _
-from fief.models import LoginSession, Tenant
+from fief.models import LoginSession, Tenant, Theme
 
 router = APIRouter()
 
@@ -23,12 +24,13 @@ async def forgot_password(
     request: Request,
     user_manager: UserManager = Depends(get_user_manager),
     tenant: Tenant = Depends(get_current_tenant),
+    theme: Theme = Depends(get_current_theme),
 ):
     form_helper = FormHelper(
         ForgotPasswordForm,
         "auth/forgot_password.html",
         request=request,
-        context={"tenant": tenant},
+        context={"tenant": tenant, "theme": theme},
     )
     form = await form_helper.get_form()
 
@@ -53,12 +55,13 @@ async def reset_password(
     user_manager: UserManager = Depends(get_user_manager),
     login_session: LoginSession | None = Depends(get_optional_login_session),
     tenant: Tenant = Depends(get_current_tenant),
+    theme: Theme = Depends(get_current_theme),
 ):
     form_helper = FormHelper(
         ResetPasswordForm,
         "auth/reset_password.html",
         request=request,
-        context={"tenant": tenant},
+        context={"tenant": tenant, "theme": theme},
     )
     form = await form_helper.get_form()
 
