@@ -1,5 +1,3 @@
-from typing import Optional
-
 from fastapi import Depends
 
 from fief.dependencies.admin_api_key import get_optional_admin_api_key
@@ -11,10 +9,9 @@ from fief.models import AdminAPIKey, AdminSessionToken, Workspace
 
 async def get_audit_logger(
     workspace: Workspace = Depends(get_current_workspace),
-    admin_session_token: Optional[AdminSessionToken] = Depends(
-        get_optional_admin_session_token
-    ),
-    admin_api_key: Optional[AdminAPIKey] = Depends(get_optional_admin_api_key),
+    admin_session_token: AdminSessionToken
+    | None = Depends(get_optional_admin_session_token),
+    admin_api_key: AdminAPIKey | None = Depends(get_optional_admin_api_key),
 ) -> AuditLogger:
     return AuditLogger(
         logger,  # type: ignore
