@@ -1,12 +1,11 @@
 import enum
-import re
 import secrets
 from datetime import datetime, timedelta, timezone
 
 from jwcrypto import jwk
 from pydantic import UUID4
-from sqlalchemy import Boolean, Column, Enum, ForeignKey, Integer, String, Text
-from sqlalchemy.orm import relationship
+from sqlalchemy import Boolean, Enum, ForeignKey, Integer, String, Text
+from sqlalchemy.orm import Mapped, mapped_column, relationship
 from sqlalchemy.sql.sqltypes import JSON
 
 from fief.crypto.jwk import load_jwk
@@ -15,10 +14,6 @@ from fief.models.generics import GUID, CreatedUpdatedAt, UUIDModel
 from fief.models.tenant import Tenant
 from fief.settings import settings
 
-LOCALHOST_HOST_PATTERN = re.compile(
-    r"([^\.]+\.)?localhost(\d+)?|127\.0\.0\.1", flags=re.IGNORECASE
-)
-
 
 def get_default_redirect_uris() -> list[str]:
     return ["http://localhost:8000/docs/oauth2-redirect"]
@@ -43,44 +38,44 @@ class ClientType(str, enum.Enum):
 class Client(UUIDModel, CreatedUpdatedAt, WorkspaceBase):
     __tablename__ = "clients"
 
-    name: str = Column(String(length=255), nullable=False)
-    first_party: bool = Column(Boolean, nullable=False, default=False)
+    name: Mapped[str] = mapped_column(String(length=255), nullable=False)
+    first_party: Mapped[bool] = mapped_column(Boolean, nullable=False, default=False)
 
-    client_type: ClientType = Column(
+    client_type: Mapped[ClientType] = mapped_column(
         Enum(ClientType, values_callable=lambda x: [e.value for e in x]),
         nullable=False,
         default=ClientType.CONFIDENTIAL,
         server_default=ClientType.CONFIDENTIAL,
     )
-    client_id: str = Column(
+    client_id: Mapped[str] = mapped_column(
         String(length=255), default=secrets.token_urlsafe, nullable=False, index=True
     )
-    client_secret: str = Column(
+    client_secret: Mapped[str] = mapped_column(
         String(length=255), default=secrets.token_urlsafe, nullable=False, index=True
     )
-    redirect_uris: list[str] = Column(
+    redirect_uris: Mapped[list[str]] = mapped_column(
         JSON, nullable=False, default=get_default_redirect_uris
     )
-    encrypt_jwk: str = Column(Text, nullable=True)
+    encrypt_jwk: Mapped[str] = mapped_column(Text, nullable=True)
 
-    authorization_code_lifetime_seconds: int = Column(
+    authorization_code_lifetime_seconds: Mapped[int] = mapped_column(
         Integer,
         nullable=False,
         default=settings.default_authorization_code_lifetime_seconds,
     )
-    access_id_token_lifetime_seconds: int = Column(
+    access_id_token_lifetime_seconds: Mapped[int] = mapped_column(
         Integer,
         nullable=False,
         default=settings.default_access_id_token_lifetime_seconds,
     )
-    refresh_token_lifetime_seconds: int = Column(
+    refresh_token_lifetime_seconds: Mapped[int] = mapped_column(
         Integer, nullable=False, default=settings.default_refresh_token_lifetime_seconds
     )
 
-    tenant_id: UUID4 = Column(
+    tenant_id: Mapped[UUID4] = mapped_column(
         GUID, ForeignKey(Tenant.id, ondelete="CASCADE"), nullable=False
     )
-    tenant: Tenant = relationship("Tenant", lazy="joined")
+    tenant: Mapped[Tenant] = relationship("Tenant", lazy="joined")
 
     def __repr__(self) -> str:
         return f"Client(id={self.id}, name={self.name}, client_id={self.client_id})"
@@ -100,5 +95,4 @@ class Client(UUIDModel, CreatedUpdatedAt, WorkspaceBase):
         return self._get_expires_at("refresh_token_lifetime_seconds")
 
     def _get_expires_at(self, attr: str) -> datetime:
-        print(attr, getattr(self, attr))
         return datetime.now(timezone.utc) + timedelta(seconds=getattr(self, attr))
