@@ -1,8 +1,8 @@
 import secrets
 
 from pydantic import UUID4
-from sqlalchemy import Column, ForeignKey, Text
-from sqlalchemy.orm import relationship
+from sqlalchemy import ForeignKey, Text
+from sqlalchemy.orm import Mapped, mapped_column, relationship
 from sqlalchemy.sql.sqltypes import String
 
 from fief.models.base import WorkspaceBase
@@ -18,31 +18,33 @@ class OAuthSession(UUIDModel, CreatedUpdatedAt, ExpiresAt, WorkspaceBase):
     __tablename__ = "oauth_sessions"
     __lifetime_seconds__ = settings.login_session_lifetime_seconds
 
-    token: str = Column(
+    token: Mapped[str] = mapped_column(
         String(length=255),
         default=secrets.token_urlsafe,
         nullable=False,
         index=True,
         unique=True,
     )
-    redirect_uri: str = Column(Text, nullable=False)
+    redirect_uri: Mapped[str] = mapped_column(Text, nullable=False)
 
-    oauth_provider_id: UUID4 = Column(
+    oauth_provider_id: Mapped[UUID4] = mapped_column(
         GUID, ForeignKey(OAuthProvider.id, ondelete="CASCADE"), nullable=False
     )
-    oauth_provider: OAuthProvider = relationship("OAuthProvider", lazy="joined")
+    oauth_provider: Mapped[OAuthProvider] = relationship("OAuthProvider", lazy="joined")
 
-    login_session_id: UUID4 = Column(
+    login_session_id: Mapped[UUID4] = mapped_column(
         GUID, ForeignKey(LoginSession.id, ondelete="CASCADE"), nullable=False
     )
-    login_session: LoginSession = relationship("LoginSession")
+    login_session: Mapped[LoginSession] = relationship("LoginSession")
 
-    oauth_account_id: UUID4 | None = Column(
+    oauth_account_id: Mapped[UUID4 | None] = mapped_column(
         GUID, ForeignKey(OAuthAccount.id, ondelete="CASCADE"), nullable=True
     )
-    oauth_account: OAuthAccount | None = relationship("OAuthAccount", lazy="joined")
+    oauth_account: Mapped[OAuthAccount | None] = relationship(
+        "OAuthAccount", lazy="joined"
+    )
 
-    tenant_id: UUID4 = Column(
+    tenant_id: Mapped[UUID4] = mapped_column(
         GUID, ForeignKey(Tenant.id, ondelete="CASCADE"), nullable=False
     )
-    tenant: Tenant = relationship("Tenant", lazy="joined")
+    tenant: Mapped[Tenant] = relationship("Tenant", lazy="joined")
