@@ -1,6 +1,6 @@
 from pydantic import UUID4
-from sqlalchemy import Column, ForeignKey, String
-from sqlalchemy.orm import relationship
+from sqlalchemy import ForeignKey, String
+from sqlalchemy.orm import Mapped, mapped_column, relationship
 
 from fief.models.base import WorkspaceBase
 from fief.models.generics import GUID, CreatedUpdatedAt, ExpiresAt, UUIDModel
@@ -12,14 +12,14 @@ class SessionToken(UUIDModel, CreatedUpdatedAt, ExpiresAt, WorkspaceBase):
     __tablename__ = "session_tokens"
     __lifetime_seconds__ = settings.session_lifetime_seconds
 
-    token: str = Column(
+    token: Mapped[str] = mapped_column(
         String(length=255),
         nullable=False,
         index=True,
         unique=True,
     )
 
-    user_id: UUID4 = Column(
+    user_id: Mapped[UUID4] = mapped_column(
         GUID, ForeignKey(User.id, ondelete="CASCADE"), nullable=False
     )
-    user: User = relationship("User", lazy="joined")
+    user: Mapped[User] = relationship("User", lazy="joined")
