@@ -1,5 +1,3 @@
-from typing import Optional
-
 from pydantic import UUID4
 from sqlalchemy import select
 
@@ -14,7 +12,7 @@ class WorkspaceUserRepository(
 
     async def get_by_workspace_and_user(
         self, workspace_id: UUID4, user_id: UUID4
-    ) -> Optional[WorkspaceUser]:
+    ) -> WorkspaceUser | None:
         statement = select(WorkspaceUser).where(
             WorkspaceUser.workspace_id == workspace_id, WorkspaceUser.user_id == user_id
         )
