@@ -1,15 +1,15 @@
-from typing import Optional, Protocol, Tuple
+from typing import Protocol
 
 
 class EmailProvider(Protocol):
     def send_email(
         self,
         *,
-        sender: Tuple[str, Optional[str]],
-        recipient: Tuple[str, Optional[str]],
+        sender: tuple[str, str | None],
+        recipient: tuple[str, str | None],
         subject: str,
-        html: Optional[str] = None,
-        text: Optional[str] = None,
+        html: str | None = None,
+        text: str | None = None,
     ):
         ...
 
@@ -23,5 +23,5 @@ class SendEmailError(EmailError):
     pass
 
 
-def format_address(email: str, name: Optional[str] = None):
+def format_address(email: str, name: str | None = None):
     return email if name is None else f"{name} <{email}>"
