@@ -97,9 +97,9 @@ class Settings(BaseSettings):
     session_cookie_secure: bool = True
     session_lifetime_seconds: int = 86400 * 30
 
-    authorization_code_lifetime_seconds: int = 600
-    access_id_token_lifetime_seconds: int = 3600
-    refresh_token_lifetime_seconds: int = 3600 * 24 * 30
+    default_authorization_code_lifetime_seconds: int = 600
+    default_access_id_token_lifetime_seconds: int = 3600 * 24
+    default_refresh_token_lifetime_seconds: int = 3600 * 24 * 30
 
     fief_domain: str = "localhost:8000"
     fief_client_id: str
