@@ -1,6 +1,6 @@
 from fief.tasks.base import SendTask, send_task
-from fief.tasks.cleanup import cleanup
-from fief.tasks.count_users import count_users
+from fief.tasks.cleanup import cleanup, cleanup_workspace
+from fief.tasks.count_users import count_users, count_users_workspace
 from fief.tasks.forgot_password import on_after_forgot_password
 from fief.tasks.register import on_after_register
 from fief.tasks.roles import on_role_updated
@@ -10,7 +10,9 @@ __all__ = [
     "send_task",
     "SendTask",
     "cleanup",
+    "cleanup_workspace",
     "count_users",
+    "count_users_workspace",
     "on_after_forgot_password",
     "on_after_register",
     "on_role_updated",
